## Load Example Data Set and Form X Matrix ##

load("HighSpeedRail.Rdata")

Y <- HighSpeedRail$Grant2010
X <- cbind(rep(1,length(Y)),HighSpeedRail$LogPopulation,HighSpeedRail$PresVote2008,HighSpeedRail$RepublicanGov2011)

## Prepare Data for JAGS ##

N <- dim(X)[1]
K <- dim(X)[2]
ZeroObs <- which(Y == 0)
NonZeroObs <- which(Y != 0)
Nzero <- length(ZeroObs)
Nnonzero <- length(NonZeroObs)

library(rjags)

## Simulate Double Equation Model ##

DoubleModel.jags <- jags.model(file="DoubleEquation.jags",n.adapt = 1000,inits=list(psi=as.numeric(Y != 0)))
update(DoubleModel.jags,1000)
DoubleModel.out <- coda.samples(DoubleModel.jags,c("beta","gamma","zeta"),n.iter= 10000)

print(summary(DoubleModel.out))

## Simulate Single Equation Model ##

SingleModel.jags <- jags.model(file="SingleEquation.jags",n.adapt = 1000,inits=list(psi=as.numeric(Y != 0)))
update(SingleModel.jags,1000)
SingleModel.out <- coda.samples(SingleModel.jags,c("beta","gamma","zeta"),n.iter= 10000)

print(summary(SingleModel.out))



